==> parsnip_1.3.3.tar.gz: parsnip/R/aaa_archive.R <==
# no fmt
model_info_table <-
    tibble::tribble(
                      ~model,                 ~mode,            ~engine,            ~pkg,
                  "bag_tree", "censored regression",            "rpart",      "censored",
                "boost_tree", "censored regression",           "mboost",      "censored",
             "decision_tree", "censored regression",         "partykit",      "censored",
             "decision_tree", "censored regression",            "rpart",      "censored",
      "proportional_hazards", "censored regression",           "glmnet",      "censored",
      "proportional_hazards", "censored regression",         "survival",      "censored",
               "rand_forest", "censored regression",            "aorsf",      "censored",
               "rand_forest", "censored regression",         "partykit",      "censored",
              "survival_reg", "censored regression",         "flexsurv",      "censored",
              "survival_reg", "censored regression",   "flexsurvspline",      "censored",
              "survival_reg", "censored regression",         "survival",      "censored",
                  "C5_rules",      "classification",             "C5.0",         "rules",
                   "auto_ml",      "classification",              "h2o",          "agua",
                  "bag_mars",      "classification",            "earth",      "baguette",
                   "bag_mlp",      "classification",             "nnet",      "baguette",
                  "bag_tree",      "classification",             "C5.0",      "baguette",
                  "bag_tree",      "classification",            "rpart",      "baguette",
                      "bart",      "classification",           "dbarts",              NA,
                "boost_tree",      "classification",             "C5.0",              NA,
                "boost_tree",      "classification",              "h2o",          "agua",
                "boost_tree",      "classification",          "h2o_gbm",          "agua",
                "boost_tree",      "classification",         "lightgbm",        "bonsai",
                "boost_tree",      "classification",            "spark",              NA,
                "boost_tree",      "classification",          "xgboost",              NA,
             "decision_tree",      "classification",             "C5.0",              NA,
             "decision_tree",      "classification",         "partykit",        "bonsai",
             "decision_tree",      "classification",            "rpart",              NA,
             "decision_tree",      "classification",            "spark",              NA,
          "discrim_flexible",      "classification",            "earth",       "discrim",
            "discrim_linear",      "classification",             "MASS",       "discrim",
            "discrim_linear",      "classification",              "mda",       "discrim",
            "discrim_linear",      "classification",              "sda",       "discrim",
            "discrim_linear",      "classification",    "sparsediscrim",       "discrim",
              "discrim_quad",      "classification",             "MASS",       "discrim",
              "discrim_quad",      "classification",    "sparsediscrim",       "discrim",
       "discrim_regularized",      "classification",             "klaR",       "discrim",
          "gen_additive_mod",      "classification",             "mgcv",              NA,
              "logistic_reg",      "classification",        "LiblineaR",              NA,
              "logistic_reg",      "classification",           "brulee",              NA,
              "logistic_reg",      "classification",              "gee", "multilevelmod",
              "logistic_reg",      "classification",              "glm",              NA,
              "logistic_reg",      "classification",            "glmer", "multilevelmod",
              "logistic_reg",      "classification",           "glmnet",              NA,
              "logistic_reg",      "classification",              "h2o",          "agua",
              "logistic_reg",      "classification",            "keras",              NA,
              "logistic_reg",      "classification",            "spark",              NA,
              "logistic_reg",      "classification",             "stan",              NA,
              "logistic_reg",      "classification",       "stan_glmer", "multilevelmod",
                      "mars",      "classification",            "earth",              NA,
                       "mlp",      "classification",           "brulee",              NA,
                       "mlp",      "classification", "brulee_two_layer",              NA,
                       "mlp",      "classification",              "h2o",          "agua",
                       "mlp",      "classification",            "keras",              NA,
                       "mlp",      "classification",             "nnet",              NA,
              "multinom_reg",      "classification",           "brulee",              NA,
              "multinom_reg",      "classification",           "glmnet",              NA,
              "multinom_reg",      "classification",              "h2o",          "agua",
              "multinom_reg",      "classification",            "keras",              NA,
              "multinom_reg",      "classification",             "nnet",              NA,
              "multinom_reg",      "classification",            "spark",              NA,
               "naive_Bayes",      "classification",              "h2o",          "agua",
               "naive_Bayes",      "classification",             "klaR",       "discrim",
               "naive_Bayes",      "classification",       "naivebayes",       "discrim",
          "nearest_neighbor",      "classification",             "kknn",              NA,
                "null_model",      "classification",          "parsnip",              NA,
                       "pls",      "classification",         "mixOmics",        "plsmod",
               "rand_forest",      "classification",            "aorsf",        "bonsai",
               "rand_forest",      "classification",              "h2o",          "agua",
               "rand_forest",      "classification",         "partykit",        "bonsai",
               "rand_forest",      "classification",     "randomForest",              NA,
               "rand_forest",      "classification",           "ranger",              NA,
               "rand_forest",      "classification",            "spark",              NA,
                  "rule_fit",      "classification",              "h2o",          "agua",
                  "rule_fit",      "classification",              "xrf",         "rules",
                "svm_linear",      "classification",        "LiblineaR",              NA,
                "svm_linear",      "classification",          "kernlab",              NA,
                  "svm_poly",      "classification",          "kernlab",              NA,
                   "svm_rbf",      "classification",          "kernlab",              NA,
                   "svm_rbf",      "classification",        "liquidSVM",              NA,
                "linear_reg", "quantile regression",         "quantreg",              NA,
                   "auto_ml",          "regression",              "h2o",          "agua",
                  "bag_mars",          "regression",            "earth",      "baguette",
                   "bag_mlp",          "regression",             "nnet",      "baguette",
                  "bag_tree",          "regression",            "rpart",      "baguette",
                      "bart",          "regression",           "dbarts",              NA,
                "boost_tree",          "regression",              "h2o",          "agua",
                "boost_tree",          "regression",          "h2o_gbm",          "agua",
                "boost_tree",          "regression",         "lightgbm",        "bonsai",
                "boost_tree",          "regression",            "spark",              NA,
                "boost_tree",          "regression",          "xgboost",              NA,
              "cubist_rules",          "regression",           "Cubist",         "rules",
             "decision_tree",          "regression",         "partykit",        "bonsai",
             "decision_tree",          "regression",            "rpart",              NA,
             "decision_tree",          "regression",            "spark",              NA,
          "gen_additive_mod",          "regression",             "mgcv",              NA,
                "linear_reg",          "regression",           "brulee",              NA,
                "linear_reg",          "regression",              "gee", "multilevelmod",
                "linear_reg",          "regression",              "glm",              NA,
                "linear_reg",          "regression",            "glmer", "multilevelmod",
                "linear_reg",          "regression",           "glmnet",              NA,
                "linear_reg",          "regression",              "gls", "multilevelmod",
                "linear_reg",          "regression",              "h2o",          "agua",
                "linear_reg",          "regression",            "keras",              NA,
                "linear_reg",          "regression",               "lm",              NA,
                "linear_reg",          "regression",              "lme", "multilevelmod",
                "linear_reg",          "regression",             "lmer", "multilevelmod",
                "linear_reg",          "regression",            "spark",              NA,
                "linear_reg",          "regression",             "stan",              NA,
                "linear_reg",          "regression",       "stan_glmer", "multilevelmod",
                      "mars",          "regression",            "earth",              NA,
                       "mlp",          "regression",           "brulee",              NA,
                       "mlp",          "regression", "brulee_two_layer",              NA,
                       "mlp",          "regression",              "h2o",          "agua",
                       "mlp",          "regression",            "keras",              NA,
                       "mlp",          "regression",             "nnet",              NA,
          "nearest_neighbor",          "regression",             "kknn",              NA,
                "null_model",          "regression",          "parsnip",              NA,
                       "pls",          "regression",         "mixOmics",        "plsmod",
               "poisson_reg",          "regression",              "gee", "multilevelmod",
               "poisson_reg",          "regression",              "glm",    "poissonreg",
               "poisson_reg",          "regression",            "glmer", "multilevelmod",
               "poisson_reg",          "regression",           "glmnet",    "poissonreg",
               "poisson_reg",          "regression",              "h2o",          "agua",
               "poisson_reg",          "regression",           "hurdle",    "poissonreg",
               "poisson_reg",          "regression",             "stan",    "poissonreg",
               "poisson_reg",          "regression",       "stan_glmer", "multilevelmod",
               "poisson_reg",          "regression",         "zeroinfl",    "poissonreg",
               "rand_forest",          "regression",            "aorsf",        "bonsai",
               "rand_forest",          "regression",              "h2o",          "agua",
               "rand_forest",          "regression",         "partykit",        "bonsai",
               "rand_forest",          "regression",     "randomForest",              NA,
               "rand_forest",          "regression",           "ranger",              NA,
               "rand_forest",          "regression",            "spark",              NA,
                  "rule_fit",          "regression",              "h2o",          "agua",
                  "rule_fit",          "regression",              "xrf",         "rules",
                  "surv_reg",          "regression",         "flexsurv",              NA,
                  "surv_reg",          "regression",         "survival",              NA,
                "svm_linear",          "regression",        "LiblineaR",              NA,
                "svm_linear",          "regression",          "kernlab",              NA,
                  "svm_poly",          "regression",          "kernlab",              NA,
                   "svm_rbf",          "regression",          "kernlab",              NA,
                   "svm_rbf",          "regression",        "liquidSVM",              NA
      )

==> parsnip_1.4.1.tar.gz: parsnip/R/aaa_archive.R <==
# fmt: skip
model_info_table <-
    tibble::tribble(
                      ~model,                 ~mode,            ~engine,            ~pkg,
                  "bag_tree", "censored regression",            "rpart",      "censored",
                "boost_tree", "censored regression",           "mboost",      "censored",
             "decision_tree", "censored regression",         "partykit",      "censored",
             "decision_tree", "censored regression",            "rpart",      "censored",
      "proportional_hazards", "censored regression",           "glmnet",      "censored",
      "proportional_hazards", "censored regression",         "survival",      "censored",
               "rand_forest", "censored regression",            "aorsf",      "censored",
               "rand_forest", "censored regression",         "partykit",      "censored",
              "survival_reg", "censored regression",         "flexsurv",      "censored",
              "survival_reg", "censored regression",   "flexsurvspline",      "censored",
              "survival_reg", "censored regression",         "survival",      "censored",
                  "C5_rules",      "classification",             "C5.0",         "rules",
                   "auto_ml",      "classification",              "h2o",          "agua",
                  "bag_mars",      "classification",            "earth",      "baguette",
                   "bag_mlp",      "classification",             "nnet",      "baguette",
                  "bag_tree",      "classification",             "C5.0",      "baguette",
                  "bag_tree",      "classification",            "rpart",      "baguette",
                      "bart",      "classification",           "dbarts",              NA,
                "boost_tree",      "classification",             "C5.0",              NA,
                "boost_tree",      "classification",         "catboost",        "bonsai",
                "boost_tree",      "classification",              "h2o",          "agua",
                "boost_tree",      "classification",          "h2o_gbm",          "agua",
                "boost_tree",      "classification",         "lightgbm",        "bonsai",
                "boost_tree",      "classification",            "spark",              NA,
                "boost_tree",      "classification",          "xgboost",              NA,
             "decision_tree",      "classification",             "C5.0",              NA,
             "decision_tree",      "classification",         "partykit",        "bonsai",
             "decision_tree",      "classification",            "rpart",              NA,
             "decision_tree",      "classification",            "spark",              NA,
          "discrim_flexible",      "classification",            "earth",       "discrim",
            "discrim_linear",      "classification",             "MASS",       "discrim",
            "discrim_linear",      "classification",              "mda",       "discrim",
            "discrim_linear",      "classification",              "sda",       "discrim",
            "discrim_linear",      "classification",    "sparsediscrim",       "discrim",
              "discrim_quad",      "classification",             "MASS",       "discrim",
              "discrim_quad",      "classification",    "sparsediscrim",       "discrim",
       "discrim_regularized",      "classification",             "klaR",       "discrim",
          "gen_additive_mod",      "classification",             "mgcv",              NA,
              "logistic_reg",      "classification",        "LiblineaR",              NA,
              "logistic_reg",      "classification",           "brulee",              NA,
              "logistic_reg",      "classification",              "gee", "multilevelmod",
              "logistic_reg",      "classification",              "glm",              NA,
              "logistic_reg",      "classification",            "glmer", "multilevelmod",
              "logistic_reg",      "classification",           "glmnet",              NA,
              "logistic_reg",      "classification",              "h2o",          "agua",
              "logistic_reg",      "classification",            "keras",              NA,
              "logistic_reg",      "classification",            "spark",              NA,
              "logistic_reg",      "classification",             "stan",              NA,
              "logistic_reg",      "classification",       "stan_glmer", "multilevelmod",
                      "mars",      "classification",            "earth",              NA,
                       "mlp",      "classification",           "brulee",              NA,
                       "mlp",      "classification", "brulee_two_layer",              NA,
                       "mlp",      "classification",              "h2o",          "agua",
                       "mlp",      "classification",            "keras",              NA,
                       "mlp",      "classification",             "nnet",              NA,
              "multinom_reg",      "classification",           "brulee",              NA,
              "multinom_reg",      "classification",           "glmnet",              NA,
              "multinom_reg",      "classification",              "h2o",          "agua",
              "multinom_reg",      "classification",            "keras",              NA,
              "multinom_reg",      "classification",             "nnet",              NA,
              "multinom_reg",      "classification",            "spark",              NA,
               "naive_Bayes",      "classification",              "h2o",          "agua",
               "naive_Bayes",      "classification",             "klaR",       "discrim",
               "naive_Bayes",      "classification",       "naivebayes",       "discrim",
          "nearest_neighbor",      "classification",             "kknn",              NA,
                "null_model",      "classification",          "parsnip",              NA,
                       "pls",      "classification",         "mixOmics",        "plsmod",
               "rand_forest",      "classification",            "aorsf",        "bonsai",
               "rand_forest",      "classification",              "grf",              NA,
               "rand_forest",      "classification",              "h2o",          "agua",
               "rand_forest",      "classification",         "partykit",        "bonsai",
               "rand_forest",      "classification",     "randomForest",              NA,
               "rand_forest",      "classification",           "ranger",              NA,
               "rand_forest",      "classification",            "spark",              NA,
                  "rule_fit",      "classification",              "h2o",          "agua",
                  "rule_fit",      "classification",              "xrf",         "rules",
                "svm_linear",      "classification",        "LiblineaR",              NA,
                "svm_linear",      "classification",          "kernlab",              NA,
                  "svm_poly",      "classification",          "kernlab",              NA,
                   "svm_rbf",      "classification",          "kernlab",              NA,
                   "svm_rbf",      "classification",        "liquidSVM",              NA,
                "linear_reg", "quantile regression",         "quantreg",              NA,
               "rand_forest", "quantile regression",              "grf",              NA,
                   "auto_ml",          "regression",              "h2o",          "agua",
                  "bag_mars",          "regression",            "earth",      "baguette",
                   "bag_mlp",          "regression",             "nnet",      "baguette",
                  "bag_tree",          "regression",            "rpart",      "baguette",
                      "bart",          "regression",           "dbarts",              NA,
                "boost_tree",          "regression",         "catboost",        "bonsai",
                "boost_tree",          "regression",              "h2o",          "agua",
                "boost_tree",          "regression",          "h2o_gbm",          "agua",
                "boost_tree",          "regression",         "lightgbm",        "bonsai",
                "boost_tree",          "regression",            "spark",              NA,
                "boost_tree",          "regression",          "xgboost",              NA,
              "cubist_rules",          "regression",           "Cubist",         "rules",
             "decision_tree",          "regression",         "partykit",        "bonsai",
             "decision_tree",          "regression",            "rpart",              NA,
             "decision_tree",          "regression",            "spark",              NA,
          "gen_additive_mod",          "regression",             "mgcv",              NA,
                "linear_reg",          "regression",           "brulee",              NA,
                "linear_reg",          "regression",              "gee", "multilevelmod",
                "linear_reg",          "regression",              "glm",              NA,
                "linear_reg",          "regression",            "glmer", "multilevelmod",
                "linear_reg",          "regression",           "glmnet",              NA,
                "linear_reg",          "regression",              "gls", "multilevelmod",
                "linear_reg",          "regression",              "h2o",          "agua",
                "linear_reg",          "regression",            "keras",              NA,
                "linear_reg",          "regression",               "lm",              NA,
                "linear_reg",          "regression",              "lme", "multilevelmod",
                "linear_reg",          "regression",             "lmer", "multilevelmod",
                "linear_reg",          "regression",            "spark",              NA,
                "linear_reg",          "regression",             "stan",              NA,
                "linear_reg",          "regression",       "stan_glmer", "multilevelmod",
                      "mars",          "regression",            "earth",              NA,
                       "mlp",          "regression",           "brulee",              NA,
                       "mlp",          "regression", "brulee_two_layer",              NA,
                       "mlp",          "regression",              "h2o",          "agua",
                       "mlp",          "regression",            "keras",              NA,
                       "mlp",          "regression",             "nnet",              NA,
          "nearest_neighbor",          "regression",             "kknn",              NA,
                "null_model",          "regression",          "parsnip",              NA,
                       "pls",          "regression",         "mixOmics",        "plsmod",
               "poisson_reg",          "regression",              "gee", "multilevelmod",
               "poisson_reg",          "regression",              "glm",    "poissonreg",
               "poisson_reg",          "regression",            "glmer", "multilevelmod",
               "poisson_reg",          "regression",           "glmnet",    "poissonreg",
               "poisson_reg",          "regression",              "h2o",          "agua",
               "poisson_reg",          "regression",           "hurdle",    "poissonreg",
               "poisson_reg",          "regression",             "stan",    "poissonreg",
               "poisson_reg",          "regression",       "stan_glmer", "multilevelmod",
               "poisson_reg",          "regression",         "zeroinfl",    "poissonreg",
               "rand_forest",          "regression",            "aorsf",        "bonsai",
               "rand_forest",          "regression",              "grf",              NA,
               "rand_forest",          "regression",              "h2o",          "agua",
               "rand_forest",          "regression",         "partykit",        "bonsai",
               "rand_forest",          "regression",     "randomForest",              NA,
               "rand_forest",          "regression",           "ranger",              NA,
               "rand_forest",          "regression",            "spark",              NA,
                  "rule_fit",          "regression",              "h2o",          "agua",
                  "rule_fit",          "regression",              "xrf",         "rules",
                  "surv_reg",          "regression",         "flexsurv",              NA,
                  "surv_reg",          "regression",         "survival",              NA,
                "svm_linear",          "regression",        "LiblineaR",              NA,
                "svm_linear",          "regression",          "kernlab",              NA,
                  "svm_poly",          "regression",          "kernlab",              NA,
                   "svm_rbf",          "regression",          "kernlab",              NA,
                   "svm_rbf",          "regression",        "liquidSVM",              NA
      )
